==> goods-center-biz-1.7.7-20161212.040916-1-sources.jar: cn/com/duiba/goods/center/biz/remoteservice/impl/RemoteGoodsAppItemExtraServiceImpl.java <==
package cn.com.duiba.goods.center.biz.remoteservice.impl;

import cn.com.duiba.goods.center.api.remoteservice.RemoteGoodsAppItemExtraService;
import cn.com.duiba.goods.center.api.remoteservice.dto.item.AppItemExtraDto;
import cn.com.duiba.goods.center.biz.service.item.AppItemExtraService;
import cn.com.duiba.wolf.dubbo.DubboResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * Created by xiaoxuda on 2016/12/6.
 */
@Service("remoteGoodsAppItemExtraService")
public class RemoteGoodsAppItemExtraServiceImpl implements RemoteGoodsAppItemExtraService {
    @Autowired
    private AppItemExtraService appItemExtraService;

    @Override
    public DubboResult<AppItemExtraDto> findByAppItemId(Long appItemId) {
        return DubboResult.successResult(appItemExtraService.findByAppItemId(appItemId));
    }

    @Override
    public DubboResult<Integer> insert(AppItemExtraDto appItemExtra) {
        return DubboResult.successResult(appItemExtraService.insert(appItemExtra));
    }

    @Override
    public DubboResult<Integer> updateByAppItemId(AppItemExtraDto appItemExtra) {
        return DubboResult.successResult(appItemExtraService.updateByAppItemId(appItemExtra));
    }

    @Override
    public DubboResult<Integer> deleteByAppItemId(Long appItemId) {
        return DubboResult.successResult(appItemExtraService.deleteByAppItemId(appItemId));
    }

    @Override
    public DubboResult<Integer> insertOrUpdateByAppItemId(AppItemExtraDto appItemExtra) {
        return DubboResult.successResult(appItemExtraService.insertOrUpdateByAppItemId(appItemExtra));
    }


}

==> goods-center-biz-1.9.1-20170204.062920-1-sources.jar: cn/com/duiba/goods/center/biz/remoteservice/impl/RemoteGoodsAppItemExtraServiceImpl.java <==
package cn.com.duiba.goods.center.biz.remoteservice.impl;

import cn.com.duiba.goods.center.api.remoteservice.RemoteGoodsAppItemExtraService;
import cn.com.duiba.goods.center.api.remoteservice.dto.item.AppItemExtraDto;
import cn.com.duiba.goods.center.biz.entity.AppItemExtraEntity;
import cn.com.duiba.goods.center.biz.service.item.AppItemExtraService;
import cn.com.duiba.wolf.dubbo.DubboResult;
import cn.com.duiba.wolf.utils.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * Created by xiaoxuda on 2016/12/6.
 */
@Service("remoteGoodsAppItemExtraService")
public class RemoteGoodsAppItemExtraServiceImpl implements RemoteGoodsAppItemExtraService {
    @Autowired
    private AppItemExtraService appItemExtraService;

    @Override
    public DubboResult<AppItemExtraDto> findByAppItemId(Long appItemId) {
        AppItemExtraEntity entity = appItemExtraService.findByAppItemId(appItemId);
        AppItemExtraDto result = entity == null ? null : BeanUtils.copy(entity, AppItemExtraDto.class);
        return DubboResult.successResult(result);
    }

    @Override
    public DubboResult<Integer> insert(AppItemExtraDto appItemExtra) {
        return DubboResult.successResult(appItemExtraService.insert(BeanUtils.copy(appItemExtra, AppItemExtraEntity.class)));
    }

    @Override
    public DubboResult<Integer> updateByAppItemId(AppItemExtraDto appItemExtra) {
        return DubboResult.successResult(appItemExtraService.updateByAppItemId(BeanUtils.copy(appItemExtra, AppItemExtraEntity.class)));
    }

    @Override
    public DubboResult<Integer> deleteByAppItemId(Long appItemId) {
        return DubboResult.successResult(appItemExtraService.deleteByAppItemId(appItemId));
    }

    @Override
    public DubboResult<Integer> insertOrUpdateByAppItemId(AppItemExtraDto appItemExtra) {
        return DubboResult.successResult(appItemExtraService.insertOrUpdateByAppItemId(BeanUtils.copy(appItemExtra, AppItemExtraEntity.class)));
    }


}
